summaryrefslogtreecommitdiffstats
path: root/parts/filecreate/filecreate_listitem.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'parts/filecreate/filecreate_listitem.cpp')
-rw-r--r--parts/filecreate/filecreate_listitem.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/parts/filecreate/filecreate_listitem.cpp b/parts/filecreate/filecreate_listitem.cpp
index 4b33514f..b6467505 100644
--- a/parts/filecreate/filecreate_listitem.cpp
+++ b/parts/filecreate/filecreate_listitem.cpp
@@ -1,7 +1,7 @@
/***************************************************************************
* Copyright (C) 2003 by Julian Rockey *
* linux@jrockey.com *
* thanks: Roberto Raggi for QSimpleRichText stuff *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU General Public License as published by *
@@ -15,12 +15,12 @@
#include <kglobal.h>
#include <kiconloader.h>
-#include <qsimplerichtext.h>
-#include <qpixmap.h>
+#include <tqsimplerichtext.h>
+#include <tqpixmap.h>
namespace FileCreate {
- ListItem::ListItem(QListView * listview, const FileType * filetype) :
+ ListItem::ListItem(TQListView * listview, const FileType * filetype) :
KListViewItem(listview), m_filetype(filetype),
m_filetypeRenderer(NULL)
{
@@ -43,7 +43,7 @@ namespace FileCreate {
void ListItem::setup()
{
if (m_filetypeRenderer) delete m_filetypeRenderer;
- m_filetypeRenderer = new QSimpleRichText( text(1), listView()->font() );
+ m_filetypeRenderer = new TQSimpleRichText( text(1), listView()->font() );
m_filetypeRenderer->setWidth(listView()->columnWidth(1));
setHeight(m_filetypeRenderer->height());
KListViewItem::setup();
@@ -61,15 +61,15 @@ namespace FileCreate {
}
}
- void ListItem::paintCell( QPainter* p, const QColorGroup& cg, int column, int width, int align )
+ void ListItem::paintCell( TQPainter* p, const TQColorGroup& cg, int column, int width, int align )
{
- QBrush brush( isSelected() ? cg.highlight() : backgroundColor() );
+ TQBrush brush( isSelected() ? cg.highlight() : backgroundColor() );
if( column == 1 ){
// m_filetypeRenderer->setWidth(width);
// setHeight(m_filetypeRenderer->height());
- m_filetypeRenderer->draw( p, 0, 0, QRect(0, 0, width, height()), cg, &brush );
+ m_filetypeRenderer->draw( p, 0, 0, TQRect(0, 0, width, height()), cg, &brush );
return;
}
@@ -79,11 +79,11 @@ namespace FileCreate {
void ListItem::init()
{
m_iconHeight = 0;
- setText(0, m_filetype->ext()!="" ? QString("." + m_filetype->ext()) : QString("") );
+ setText(0, m_filetype->ext()!="" ? TQString("." + m_filetype->ext()) : TQString("") );
setText(1, "<qt><b>"+m_filetype->name()+"</b>. " + m_filetype->descr() );
KIconLoader * loader = KGlobal::iconLoader();
- QPixmap iconPix = loader->loadIcon(m_filetype->icon(), KIcon::Desktop,
+ TQPixmap iconPix = loader->loadIcon(m_filetype->icon(), KIcon::Desktop,
KIcon::SizeMedium,
KIcon::DefaultState, NULL,
true);
@@ -1,7 +1,7 @@
* Copyright (C) 2003 by Julian Rockey *
* linux@jrockey.com *
- * thanks: Roberto Raggi for QSimpleRichText stuff *
+ * thanks: Roberto Raggi for TQSimpleRichText stuff *
* *
* This program is free software; you can redistribute it and/or modify *